@@ -47,9 +47,9 @@ class ComputeMetafeaturesPrimitive(transformer.TransformerPrimitiveBase[Inputs,
                 ],
             },
             'installation': [{
-               'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m',
-                'version': '2022.3.28',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
+                'package': 'd3m-common-primitives',
+                'version': '2022.5.26',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.DATA_PROFILING,
