@@ -138,8 +138,8 @@ class DataFrameDatasetMapPrimitive(unsupervised_learning.UnsupervisedLearnerPrim
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m',
-                'version': '2022.3.28',
+                'package': 'd3m-common-primitives',
+                'version': '2022.5.26',
             }],
             'algorithm_types': [
                 # TODO: Change to "MAP".
