@@ -306,8 +306,8 @@ class RandomForestClassifierPrimitive(ProbabilisticCompositionalityMixin[Inputs,
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m',
-                'version': '2022.3.28',
+                'package': 'd3m-common-primitives',
+                'version': '2022.5.26',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.RANDOM_FOREST,
