@@ -259,8 +259,8 @@ class XGBoostGBTreeRegressorPrimitive(SamplingCompositionalityMixin[Inputs, Outp
             },
             'installation': [{
                 'type': metadata_base.PrimitiveInstallationType.PIP,
-                'package': 'd3m',
-                'version': '2022.3.28',
+                'package': 'd3m-common-primitives',
+                'version': '2022.5.26',
             }],
             'algorithm_types': [
                 metadata_base.PrimitiveAlgorithmType.GRADIENT_BOOSTING,
